@@ -12,9 +12,8 @@ after 'update' => sub {
    my $self   = shift;
    my $source = $self->can( 'result_source' )
               ? $self->result_source : $self->_source;
-   my $hook   = $source->schema->post_update_hook;
+   my $hook   = $source->schema->post_update_hook; $hook and $hook->( $self );
 
-   $hook and $hook->( $self );
    return;
 };
 
@@ -44,6 +43,8 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 Name
 
 File::UnixAuth::Result - Unix authentication and authorisation file custom results
